Django Eldarion Ajax
====================

.. image:: https://img.shields.io/travis/eldarion/django-eldarion-ajax.svg
   :target: https://travis-ci.org/eldarion/django-eldarion-ajax

.. image:: https://img.shields.io/coveralls/eldarion/django-eldarion-ajax.svg
   :target: https://coveralls.io/r/eldarion/django-eldarion-ajax

.. image:: https://img.shields.io/pypi/dm/django-eldarion-ajax.svg
   :target:  https://pypi.python.org/pypi/django-eldarion-ajax/

.. image:: https://img.shields.io/pypi/v/django-eldarion-ajax.svg
   :target:  https://pypi.python.org/pypi/django-eldarion-ajax/

.. image:: https://img.shields.io/badge/license-MIT-blue.svg
   :target:  https://pypi.python.org/pypi/django-eldarion-ajax/


a companion app to `eldarion-ajax`_ providing base views and mixins to make
hooking up views in your project even easier


.. _eldarion-ajax: https://github.com/eldarion/eldarion-ajax
